# Changelog

## [0.0.36a4](https://github.com/OpenVoiceOS/ovos-utils/tree/0.0.36a4) (2023-09-05)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.36a3...0.0.36a4)

**Implemented enhancements:**

- IntentServiceInterface Tests and Minor Fixes [\#186](https://github.com/OpenVoiceOS/ovos-utils/pull/186) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.36a3](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.36a3) (2023-08-17)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.36a2...V0.0.36a3)

**Fixed bugs:**

- remove \_HACK [\#184](https://github.com/OpenVoiceOS/ovos-utils/pull/184) ([JarbasAl](https://github.com/JarbasAl))

**Closed issues:**

- \_\_HACK\_preload in file\_utils.py causes circular import when launching ovos\_dinkum\_listener [\#183](https://github.com/OpenVoiceOS/ovos-utils/issues/183)

## [V0.0.36a2](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.36a2) (2023-08-07)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.36a1...V0.0.36a2)

**Fixed bugs:**

- HACK / speed up resolve\_ovos\_resource\_file [\#182](https://github.com/OpenVoiceOS/ovos-utils/pull/182) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.36a1](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.36a1) (2023-08-07)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.35...V0.0.36a1)

**Merged pull requests:**

- Update `events` module docs and default values [\#181](https://github.com/OpenVoiceOS/ovos-utils/pull/181) ([NeonDaniel](https://github.com/NeonDaniel))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
